@@ -2,7 +2,8 @@ from __future__ import print_function
 
 try:
     from .util import Util
-except:
+except Exception as e:
+    # print(e)
     from .flask.utilx import Util
 
 def append_error(params, err):
